@@ -42,6 +42,7 @@ from flask_jwt_extended.exceptions import WrongTokenError
 from flask_jwt_extended.tokens import _decode_jwt
 from flask_jwt_extended.tokens import _encode_jwt
 from flask_jwt_extended.typing import ExpiresDelta
+from flask_jwt_extended.typing import Fresh
 from flask_jwt_extended.utils import current_user_context_processor
 
 
@@ -55,7 +56,9 @@ class JWTManager(object):
     to your app in a factory function.
     """
 
-    def __init__(self, app: Flask = None, add_context_processor: bool = False) -> None:
+    def __init__(
+        self, app: Optional[Flask] = None, add_context_processor: bool = False
+    ) -> None:
         """
         Create the JWTManager instance. You can either pass a flask application
         in directly here to register this extension with the flask app, or
@@ -491,8 +494,8 @@ class JWTManager(object):
         identity: Any,
         token_type: str,
         claims=None,
-        fresh: bool = False,
-        expires_delta: ExpiresDelta = None,
+        fresh: Fresh = False,
+        expires_delta: Optional[ExpiresDelta] = None,
         headers=None,
     ) -> str:
         header_overrides = self._jwt_additional_header_callback(identity)
